@@ -1095,9 +1095,13 @@ class ModuleNode(Nodes.Node, Nodes.BlockNode):
             static int
             import_%(name)s(PyObject *module)
             {
-                if (module != NULL) {
-                    PyObject *c_api_init = PyObject_GetAttrString(
-                                               module, "_import_c_api");
+                if (module != NULL)
+                {
+                    int (*init)(struct {const char *s; const void **p;}*);
+                    PyObject* c_api_init;
+
+                    c_api_init = PyObject_GetAttrString(module,
+                                                        "_import_c_api");
                     if (!c_api_init)
                         return -1;
                     if (!PyCObject_Check(c_api_init))
@@ -1108,10 +1112,10 @@ class ModuleNode(Nodes.Node, Nodes.BlockNode):
                         return -1;
                     }
 
-                    int (*init)(struct {const char *s; const void **p;}*) =
-                        PyCObject_AsVoidPtr(c_api_init);
+                    init = PyCObject_AsVoidPtr(c_api_init);
                     Py_DECREF(c_api_init);
-                    if (!init) {
+                    if (!init)
+                    {
                         PyErr_SetString(PyExc_RuntimeError,
                             "%(name)s module returned NULL pointer for C-API init function");
                         return -1;
