@@ -11,9 +11,10 @@ for IO related test cases.
 import unittest, doctest
 import os, re, shutil, tempfile, copy
 
-from common_imports import StringIO, etree, ElementTree, HelperTestCase, fileInTestDir, canonicalize
+from common_imports import StringIO, etree, ElementTree
+from common_imports import HelperTestCase, fileInTestDir, canonicalize
 
-class ETreeTestCaseBase(unittest.TestCase):
+class ETreeTestCaseBase(HelperTestCase):
     etree = None
     
     def setUp(self):
@@ -622,6 +623,14 @@ class ETreeTestCaseBase(unittest.TestCase):
             self.assertEquals(
                 '<doc%s>This is a test.</doc%s>' % (i, i),
                 canonicalize(data))
+        
+    def test_write_fail(self):
+        ElementTree = self.etree.ElementTree
+        XML = self.etree.XML
+
+        tree = ElementTree( XML('<doc>This is a test.</doc>') )
+        self.assertRaises(IOError, tree.write,
+                          "definitely////\\-\\nonexisting\\-\\////FILE")
 
     # this could trigger a crash, apparently because the document
     # reference was prematurely garbage collected
@@ -2311,6 +2320,15 @@ class ETreeTestCaseBase(unittest.TestCase):
         self.assertEquals(a1.tag, "{myns}a")
         self.assertEquals(a2.tag, "{myns}a")
 
+    def test_qname_cmp(self):
+        etree = self.etree
+        qname1 = etree.QName('myns', 'a')
+        qname2 = etree.QName('myns', 'a')
+        self.assertEquals(qname1, "{myns}a")
+        self.assertEquals("{myns}a", qname2)
+        self.assertEquals(qname1, qname1)
+        self.assertEquals(qname1, qname2)
+
     def _writeElement(self, element, encoding='us-ascii'):
         """Write out element for comparison.
         """
